summaryrefslogtreecommitdiff
path: root/addons/mail/static/src/scss/thread.scss
diff options
context:
space:
mode:
authorqsm-odoo <qsm@odoo.com>2018-02-15 18:14:58 +0100
committerqsm-odoo <qsm@odoo.com>2018-04-18 15:59:18 +0200
commitfbfd0119041ca7dc830796e76d9ae5c303459d4f (patch)
treee30dd1a85988a97411a6d00945248fa1166cf465 /addons/mail/static/src/scss/thread.scss
parent97aa0a8dec384ad75eb66045f43384b6e54f1d6e (diff)
[REF] *: get rid of introduced @​extend
During first scss convertion, classes called as mixins were changed to an @​extend instruction which was the best approximation given the fact there is no equivalent in sass to do that. The problem is that the instruction is slowing the scss computation a lot and might also break the style in unexpected ways because of the complex unwanted selectors the instruction induces. This commit removes the need of extends. This is done case per case. Sometimes this involves adding classes in xml, sometimes to change the style a little, ... The button rendering refactoring which was made at the start of the LESS to SASS merge was also done in prevision of this. After this commit, sass computation is like 5-6 times faster than less computation while it was like 10 times *slower* before this commit.
Diffstat (limited to 'addons/mail/static/src/scss/thread.scss')
-rw-r--r--addons/mail/static/src/scss/thread.scss4
1 files changed, 0 insertions, 4 deletions
diff --git a/addons/mail/static/src/scss/thread.scss b/addons/mail/static/src/scss/thread.scss
index 9f9ace65de9..4a2edb68913 100644
--- a/addons/mail/static/src/scss/thread.scss
+++ b/addons/mail/static/src/scss/thread.scss
@@ -144,10 +144,6 @@
.o_mail_info {
margin-bottom: 2px;
- @extend .text-muted; // FIXME was a mixin before scss convertion
- .o_mail_mailto, .o_mail_mailto:hover {
- @extend .text-muted; // FIXME was a mixin before scss convertion
- }
strong {
color: $headings-color;